package hornetQ.client;

import java.util.HashMap;
import org.hornetq.api.core.HornetQException;
import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.core.client.ClientConsumer;
import org.hornetq.api.core.client.ClientMessage;
import org.hornetq.api.core.client.ClientProducer;
import org.hornetq.api.core.client.ClientSession;
import org.hornetq.api.core.client.ClientSessionFactory;
import org.hornetq.api.core.client.HornetQClient;
import org.hornetq.core.remoting.impl.netty.NettyConnectorFactory;

public class ClusteredTopicDivertTest {

	public static void main(String[] args) throws HornetQException {
		ClientSession clientSession1 = null;
		ClientSession clientSession2 = null;
		try
		{
			// Create two sessions
			
			HashMap<String, Object> map = new HashMap<String, Object>();
			map.put("host", "localhost");
			map.put("port", 5445);
			TransportConfiguration config1 = new TransportConfiguration(NettyConnectorFactory.class.getName(), map);
			ClientSessionFactory clientSessionFactory1 = HornetQClient.createClientSessionFactory(config1);
			
			clientSession1 = clientSessionFactory1.createSession(false, true, true);
			clientSession1.start();
			
			map.put("port", 5446);
			
			TransportConfiguration config2 = new TransportConfiguration(NettyConnectorFactory.class.getName(), map);
			ClientSessionFactory clientSessionFactory2 = HornetQClient.createClientSessionFactory(config2);
			
			clientSession2 = clientSessionFactory2.createSession(false, true, true);
			clientSession2.start();
			
			// Create consumers on jms.queue.clusterTopic on both servers
			
			ClientConsumer consumer1 = clientSession1.createConsumer("jms.queue.clusterTopic1");
			ClientConsumer consumer2 = clientSession2.createConsumer("jms.queue.clusterTopic2");
			
			// Create a consumer on jms.queue.deliveryTopic on Server2
			
			ClientConsumer consumer3 = clientSession2.createConsumer("jms.queue.deliveryTopic");
			
			// Send a message to Server1
			
			ClientProducer producer = clientSession1.createProducer("jms.topic.clusterTopic");
			ClientMessage msg = clientSession1.createMessage(true);
			msg.getBodyBuffer().writeString("Message to jms.topic.clusterTopic on Server1");
			producer.send(msg);
			
			System.out.println("Sent a message to clusterTopic on Server1");
			
			// Receive the messages
			
			ClientMessage msg1 = consumer1.receive(1000);
			if (msg1 != null)
			{
				msg1.acknowledge();
				System.out.println("Received on Server1 (clusterTopic): " + msg1.getBodyBuffer().readString());
			}
			
			ClientMessage msg2 = consumer2.receive(1000);
			if (msg2 != null)
			{
				msg2.acknowledge();
				System.out.println("Received on Server2 (clusterTopic): " + msg2.getBodyBuffer().readString());
			}
			
			ClientMessage msg3 = consumer3.receive(1000);
			if (msg3 != null)
			{
				msg3.acknowledge();
				System.out.println("Received on Server2 (deliveryTopic): " + msg3.getBodyBuffer().readString());
			}
			else
			{
				System.out.println("! Did not receive message on deliveryTopic");
			}
			
			// Send a message to Server2
			
			producer = clientSession2.createProducer("jms.topic.clusterTopic");
			msg = clientSession2.createMessage(true);
			msg.getBodyBuffer().writeString("Message to jms.topic.clusterTopic on Server2");
			producer.send(msg);
			
			System.out.println("Sent a message to clusterTopic on Server2");
			
			// Receive the messages
			
			ClientMessage msg4 = consumer1.receive(1000);
			if (msg4 != null)
			{
				msg4.acknowledge();
				System.out.println("Received on Server1 (clusterTopic): " + msg4.getBodyBuffer().readString());
			}
			
			ClientMessage msg5 = consumer2.receive(1000);
			if (msg5 != null)
			{
				msg5.acknowledge();
				System.out.println("Received on Server2 (clusterTopic): " + msg5.getBodyBuffer().readString());
			}
			
			ClientMessage msg6 = consumer3.receive(1000);
			if (msg6 != null)
			{
				msg6.acknowledge();
				System.out.println("Received on Server2 (deliveryTopic): " + msg6.getBodyBuffer().readString());
			}
			else
			{
				System.out.println("! Did not receive message on deliveryTopic");
			}
		}
		finally
		{
			clientSession1.close();
			clientSession2.close();
		}
	}

}
